# moldudp_codec

## Purpose
This library provides easy to use codec for processing network packet using <a href="http://www.nasdaqtrader.com/content/technicalsupport/specifications/dataproducts/moldudp64.pdf">MoldUDP64</a> protocol from NASDAQ.

## Installation
pip3 install moldudp_codec

## Usage
Check samples/codec_test.py for details.

## Requirements
- Python >= 3.0

## Disclaimer
I am a newbie to Python but learning. Code works when all python script files are residing in the same directory. I am still in the process of converting this project into library/module via setup.py.
